package com.ruoyi.web.controller.oa;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.utils.SnowFlake;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.oa.domain.CmcSettleSummary;
import com.ruoyi.oa.service.ICmcSettleSummaryService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * cmc结算汇总Controller
 * 
 * @author cmc
 * @date 2024-04-29
 */
@RestController
@RequestMapping("/oa/settleSummary")
public class CmcSettleSummaryController extends BaseController
{
    @Autowired
    private ICmcSettleSummaryService cmcSettleSummaryService;

    /**
     * 查询cmc结算汇总列表
     */
    @GetMapping("/list")
    public TableDataInfo list(CmcSettleSummary cmcSettleSummary)
    {
        startPage();
        List<CmcSettleSummary> list = cmcSettleSummaryService.selectCmcSettleSummaryList(cmcSettleSummary);
        return getDataTable(list);
    }

    /**
     * 导出cmc结算汇总列表
     */
    @Log(title = "cmc结算汇总", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CmcSettleSummary cmcSettleSummary)
    {
        List<CmcSettleSummary> list = cmcSettleSummaryService.selectCmcSettleSummaryList(cmcSettleSummary);
        ExcelUtil<CmcSettleSummary> util = new ExcelUtil<CmcSettleSummary>(CmcSettleSummary.class);
        util.exportExcel(response, list, "cmc结算汇总数据");
    }

    /**
     * 获取cmc结算汇总详细信息
     */
    @GetMapping(value = "/{settleId}")
    public AjaxResult getInfo(@PathVariable("settleId") String settleId)
    {
        return success(cmcSettleSummaryService.selectCmcSettleSummaryBySettleId(settleId));
    }

    /**
     * 新增cmc结算汇总
     */
    @Log(title = "cmc结算汇总", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CmcSettleSummary cmcSettleSummary)
    {
        return toAjax(cmcSettleSummaryService.insertCmcSettleSummary(cmcSettleSummary));
    }

    /**
     * 修改cmc结算汇总
     */
    @Log(title = "cmc结算汇总", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CmcSettleSummary cmcSettleSummary)
    {
        return toAjax(cmcSettleSummaryService.updateCmcSettleSummary(cmcSettleSummary));
    }

    /**
     * 删除cmc结算汇总
     */
    @Log(title = "cmc结算汇总", businessType = BusinessType.DELETE)
	@DeleteMapping("/{settleIds}")
    public AjaxResult remove(@PathVariable String[] settleIds)
    {
        return toAjax(cmcSettleSummaryService.deleteCmcSettleSummaryBySettleIds(settleIds));
    }
}
