package com.ruoyi.web.controller.oa;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.oa.domain.CmcSupply;
import com.ruoyi.oa.service.ICmcSupplyService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * cmc用品信息Controller
 * 
 * @author cmc
 * @date 2024-04-25
 */
@RestController
@RequestMapping("/oa/supply")
public class CmcSupplyController extends BaseController
{
    @Autowired
    private ICmcSupplyService cmcSupplyService;

    /**
     * 查询cmc用品信息列表
     */
    @GetMapping("/list")
    public TableDataInfo list(CmcSupply cmcSupply)
    {
        startPage();
        List<CmcSupply> list = cmcSupplyService.selectCmcSupplyList(cmcSupply);
        return getDataTable(list);
    }

    /**
     * 导出cmc用品信息列表
     */
    @Log(title = "cmc用品信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CmcSupply cmcSupply)
    {
        List<CmcSupply> list = cmcSupplyService.selectCmcSupplyList(cmcSupply);
        ExcelUtil<CmcSupply> util = new ExcelUtil<CmcSupply>(CmcSupply.class);
        util.exportExcel(response, list, "cmc用品信息数据");
    }

    /**
     * 获取cmc用品信息详细信息
     */
    @GetMapping(value = "/{supplyId}")
    public AjaxResult getInfo(@PathVariable("supplyId") Long supplyId)
    {
        return success(cmcSupplyService.selectCmcSupplyBySupplyId(supplyId));
    }

    /**
     * 新增cmc用品信息
     */
    @Log(title = "cmc用品信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CmcSupply cmcSupply)
    {
        return toAjax(cmcSupplyService.insertCmcSupply(cmcSupply));
    }

    /**
     * 修改cmc用品信息
     */
    @Log(title = "cmc用品信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CmcSupply cmcSupply)
    {
        return toAjax(cmcSupplyService.updateCmcSupply(cmcSupply));
    }

    /**
     * 删除cmc用品信息
     */
    @Log(title = "cmc用品信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{supplyIds}")
    public AjaxResult remove(@PathVariable Long[] supplyIds)
    {
        return toAjax(cmcSupplyService.deleteCmcSupplyBySupplyIds(supplyIds));
    }
}
