package com.ruoyi.oa.service.impl;

import java.util.List;

import com.ruoyi.oa.domain.CmcProject;
import com.ruoyi.oa.domain.CmcProject;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.oa.mapper.CmcProjectMapper;
import com.ruoyi.oa.domain.CmcProject;
import com.ruoyi.oa.service.ICmcProjectService;

/**
 * cmc项目Service业务层处理
 * 
 * @author cmc
 * @date 2024-01-30
 */
@Service
public class CmcProjectServiceImpl implements ICmcProjectService 
{
    @Autowired
    private CmcProjectMapper cmcProjectMapper;

    /**
     * 查询cmc项目
     *
     * @param projectId cmc项目主键
     * @return cmc项目
     */
    @Override
    public CmcProject selectCmcProjectByProjectId(String projectId)
    {
        return cmcProjectMapper.selectCmcProjectByProjectId(projectId);
    }

    /**
     * 查询cmc项目
     *
     * @param projectNumber cmc项目编号
     * @return cmc项目
     */
    @Override
    public CmcProject selectCmcProjectByProjectNumber(String projectNumber)
    {
        return cmcProjectMapper.selectCmcProjectByProjectNumber(projectNumber);
    }

    /**
     * 获取项目负责人负责的项目详细信息
     *
     * @param projectLeader cmc项目负责人
     * @return cmc项目集合
     */
    @Override
    public List<CmcProject> selectCmcProjectListByProjectLeader(String projectLeader) {
        return cmcProjectMapper.selectCmcProjectListByProjectLeader(projectLeader);
    }

    /**
     * 查询cmc项目列表
     * 
     * @param cmcProject cmc项目
     * @return cmc项目
     */
    @Override
    public List<CmcProject> selectCmcProjectList(CmcProject cmcProject)
    {
        return cmcProjectMapper.selectCmcProjectList(cmcProject);
    }

    /**
     * 新增cmc项目
     * 
     * @param cmcProject cmc项目
     * @return 结果
     */
    @Override
    public int insertCmcProject(CmcProject cmcProject)
    {
        return cmcProjectMapper.insertCmcProject(cmcProject);
    }

    /**
     * 修改cmc项目
     * 
     * @param cmcProject cmc项目
     * @return 结果
     */
    @Override
    public int updateCmcProject(CmcProject cmcProject)
    {
        return cmcProjectMapper.updateCmcProject(cmcProject);
    }

    /**
     * 批量删除cmc项目
     * 
     * @param projectIds 需要删除的cmc项目主键
     * @return 结果
     */
    @Override
    public int deleteCmcProjectByProjectIds(String[] projectIds)
    {
        return cmcProjectMapper.deleteCmcProjectByProjectIds(projectIds);
    }

    /**
     * 删除cmc项目信息
     * 
     * @param projectId cmc项目主键
     * @return 结果
     */
    @Override
    public int deleteCmcProjectByProjectId(String projectId)
    {
        return cmcProjectMapper.deleteCmcProjectByProjectId(projectId);
    }
}
